summaryrefslogtreecommitdiff
path: root/jstests/auth/mongos_cache_invalidation.js
diff options
context:
space:
mode:
authorAndreas Nilsson <andreas.nilsson@mongodb.com>2016-08-04 18:21:16 -0400
committerAndreas Nilsson <andreas.nilsson@mongodb.com>2016-08-05 12:35:05 -0400
commit6ab376813cde9a520f6625992e3f4f645e3030e3 (patch)
tree9ebcb67ae5ac4f3afbefb9b1298251dd662bf71d /jstests/auth/mongos_cache_invalidation.js
parent8e7ab6c77df70cc1bc70c34d873f5d05f705e225 (diff)
downloadmongo-6ab376813cde9a520f6625992e3f4f645e3030e3.tar.gz
SERVER-25447 Increase timeout in mongos_cache_invalidation.js
Diffstat (limited to 'jstests/auth/mongos_cache_invalidation.js')
-rw-r--r--jstests/auth/mongos_cache_invalidation.js11
1 files changed, 4 insertions, 7 deletions
diff --git a/jstests/auth/mongos_cache_invalidation.js b/jstests/auth/mongos_cache_invalidation.js
index 6bfbd339be4..27f470338cb 100644
--- a/jstests/auth/mongos_cache_invalidation.js
+++ b/jstests/auth/mongos_cache_invalidation.js
@@ -153,13 +153,10 @@ db3.auth('spencer', 'pwd');
// s0/db1 should update its cache instantly
assert.writeOK(db1.foo.update({}, {$inc: {a: 1}}));
- // s1/db2 should update its cache in 5 seconds.
- assert.soon(
- function() {
- return !db2.foo.update({}, {$inc: {a: 1}}).hasWriteError();
- },
- "Mongos did not update its user cache after 5 seconds",
- 6 * 1000); // Give an extra 1 second to avoid races
+ // s1/db2 should update its cache in 10 seconds.
+ assert.soon(function() {
+ return !db2.foo.update({}, {$inc: {a: 1}}).hasWriteError();
+ }, "Mongos did not update its user cache after 10 seconds", 10 * 1000);
// We manually invalidate the cache on s1/db3.
db3.adminCommand("invalidateUserCache");